import {Stat} from "./datatypes.ts";
import {
  bat0,
  bat1,
  bat2,
  charm0, charm1,
  charm2,
  lore0,
  lore1,
  lore2,
  party0,
  party1,
  party2,
  stare0,
  stare1,
  stare2,
  stealth0,
  stealth1,
  stealth2
} from "./skills.ts";
import {CheckData} from "./newmap.ts";



export type VaultTemplate = {
  stats: {primary: Stat, secondary: Stat},
  checks: [CheckData, CheckData]
}

export const standardVaultTemplates: VaultTemplate[] = [
  {
    // zoo
    stats: {primary: "AGI", secondary: "PSI"},
    checks: [
      {
        label: "You're blocked from further access by a sturdy-looking brick wall. Playful bats swoop close to the alligators behind the bars.",
        options: [{
          skill: () => lore1,
          locked: "Looks sturdy.",
          unlockable: "Find a weakness.",
        }, {
          skill: () => stare0,
          locked: "Admire the bats.",
          unlockable: "Get chiropteran help.",
        }],
      },
      {
        label: "There's no person-sized route to the backroom -- only a tiny bat-sized opening.",
        options: [{
          skill: () => bat2,
          locked: "So small!",
          unlockable: "Crawl in.",
        }],
      },
    ]
  },
  {
    // blood bank
    stats: {primary: "AGI", secondary: "INT"},
    checks: [
      {
        label: "The nice lady at the counter says you can't have any blood without a doctor's note.",
        options: [
          {
            skill: () => stare1,
            locked: "Stare at the blood",
            unlockable: "Hypnotize her.",
          },
          {
            skill: () => lore0,
            locked: "Pace awkwardly.",
            unlockable: "Explain vampires.",
          },
        ],
      },
      {
        label: "There's a security camera watching the blood.",
        options: [{
          skill: () => stealth2,
          locked: "Better not.",
          unlockable: "Sneak past."
        }],
      },
    ]
  },
  {
    // coffee shop
    stats: {primary: "PSI", secondary: "CHA"},
    checks: [
      {
        label: "You don't actually drink coffee, so you probably wouldn't fit in inside.",
        options: [{
          skill: () => stealth1,
          locked: "Cringe at the thought.",
          unlockable: "Sip zealously.",
        }, {
          skill: () => bat0,
          locked: "Throat feels dry.",
          unlockable: "Fracture teacup.",
        }],
      },
      {
        label: "There's a little studio back here for getting photos -- you weren't thinking about getting your photo taken, were you?",
        options: [{
          skill: () => charm2,
          locked: "Not photogenic enough.",
          unlockable: "Be dazzling.",
        }],
      },
    ]
  },
  {
    // optometrist
    stats: {primary: "PSI", secondary: "PSI"},
    checks: [
      {
        label: "The glasses person doesn't have time for you unless you have a prescription that needs filling.",
        options: [{
          skill: () => charm1,
          locked: "That's too bad.",
          unlockable: "Insist you want one.",
        }, {
          skill: () => party0,
          locked: "Squint at him.",
          unlockable: "Drink a whole bottle of glasses cleaner.",
        }],
      },
      {
        label: "The intimidating, massive Eyeball Machine is not going to dispense a prescription for a vampire. It is far too smart for you.",
        options: [{
          skill: () => stare2,
          locked: "Indeed.",
          unlockable: "A worthy opponent."
        }],
      },
    ]
  },
  {
    // club,
    stats: {primary: "CHA", secondary: "PSI"},
    checks: [
      {
        label: "You're not here to party, are you? Vampires are total nerds! Everyone's going to laugh at you and say you're totally uncool.",
        options: [{
          skill: () => bat1,
          locked: "So awkward!",
          unlockable: "Demonstrate a new dance.",
        }, {
          skill: () => stealth0,
          locked: "Cry for help.",
          unlockable: "Say nothing.",
        }],
      },
      {
        label: "This illegal poker game consists of individuals as different from ordinary people as you are. This guy is dropping _zero_ tells.",
        options: [{
          skill: () => party2,
          locked: "Lose money.",
          unlockable: "Make him leave.",
        }],
      },
    ]
  },
  {
    // library
    stats: {primary: "INT", secondary: "CHA"},
    checks: [
      {
        label: "Special Collections. This guy is not just a librarian -- he's a vampire, too -- which he makes no effort to hide.",
        options: [{
          skill: () => party1,
          locked: "Quietly do nothing.",
          unlockable: "Be super loud.",
        }, {
          skill: () => charm0,
          locked: "Gawk at him.",
          unlockable: "Say he's cool.",
        }],
      },
      {
        label: "The librarian took a big risk letting you in back here. He's obviously deciding whether or not he's made a mistake.",
        options: [{
          skill: () => lore2,
          locked: "Look at the books.",
          unlockable: "Prove you read something."
        }],
      },
    ]
  },
]